pilas.motores.motor_qt.SonidoPhonon

Package pilas :: Package motores :: Module motor_qt :: Class SonidoPhonon |
[hide private]
[frames] | no frames]

# Class SonidoPhonon

source code

Instance Methods | [hide private]
__init__(self, media, ruta) | source code
reproducir(self) | source code
detener(self) Detiene el audio. | source code
pausar(self) Hace una pausa del audio. | source code
continuar(self) Continúa reproduciendo el audio. | source code

Class Variables | [hide private]
| deshabilitado = `False`